==> ukui-greeter_1.2.5.orig.tar.gz: ukui-greeter/ukui-greeter/translations/es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>BioAuthentication</name>
    <message>
        <source>authentication failed, restart after 2 seconds</source>
        <translation type="obsolete">autenticación fallida, reinicie después de 2 segundos</translation>
    </message>
</context>
<context>
    <name>BioDeviceView</name>
    <message>
        <source>password login</source>
        <translation type="obsolete">contraseña de acceso</translation>
    </message>
    <message>
        <source>fingerprint</source>
        <translation type="obsolete">huella dactilar</translation>
    </message>
    <message>
        <source>fingerevin</source>
        <translation type="obsolete">fingerevin</translation>
    </message>
    <message>
        <source>iris</source>
        <translation type="obsolete">iris</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FakeDialog</name>
    <message>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GreeterWindow</name>
    <message>
        <source>CN</source>
        <translation type="obsolete">CN</translation>
    </message>
    <message>
        <source>EN</source>
        <translation type="obsolete">ES</translation>
    </message>
</context>
<context>
    <name>GreeterWrapper</name>
    <message>
        <source>failed to start session.</source>
        <translation>Error al iniciar sesión.</translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <source>Login</source>
        <translation type="obsolete">Iniciar sesión</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginWindow</name>
    <message>
        <source>Login</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <source>logged in</source>
        <translation>conectado</translation>
    </message>
    <message>
        <source>login</source>
        <translation>iniciar sesión</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Contraseña: </translation>
    </message>
    <message>
        <source>login:</source>
        <translation>iniciar sesión:</translation>
    </message>
    <message>
        <source>Incorrect password, please input again</source>
        <translation type="unfinished">Contraseña incorrecta, por favor ingrese nuevamente</translation>
    </message>
    <message>
        <source>please select the type of authentication</source>
        <translation type="obsolete">Por favor seleccione el tipo de autenticación</translation>
    </message>
    <message>
        <source>Incorrect user name, please input again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished">Ventana principal</translation>
    </message>
</context>
<context>
    <name>PowerWindow</name>
    <message>
        <source>Goodbye. Would you like to…</source>
        <translation type="obsolete">Adiós. Te gustaria…</translation>
    </message>
    <message>
        <source>Other users are currently logged in to this computer, shutting down now will also close these other sessions.</source>
        <translation>Otros usuarios están actualmente conectados a esta computadora, apagar ahora también cerrará estas otras sesiones.</translation>
    </message>
    <message>
        <source>suspend</source>
        <translation>suspender</translation>
    </message>
    <message>
        <source>hibernate</source>
        <translation>hibernar</translation>
    </message>
    <message>
        <source>restart</source>
        <translation>reiniciar</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation>apagar</translation>
    </message>
    <message>
        <source>Goodbye. Would you like to...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionWindow</name>
    <message>
        <source>select the desktop environment</source>
        <translation type="obsolete">seleccione el entorno de escritorio</translation>
    </message>
    <message>
        <source> (Default)</source>
        <translation type="vanished"> (Defecto)</translation>
    </message>
</context>
<context>
    <name>UserEntry</name>
    <message>
        <source>logged in</source>
        <translation type="vanished">conectado</translation>
    </message>
</context>
<context>
    <name>UsersModel</name>
    <message>
        <source>Guest Session</source>
        <translation>Sesión de invitado</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ukui-greeter_3.0.1.orig.tar.gz: ukui-greeter/ukui-greeter/translations/es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>BioAuthentication</name>
    <message>
        <source>authentication failed, restart after 2 seconds</source>
        <translation type="obsolete">autenticación fallida, reinicie después de 2 segundos</translation>
    </message>
</context>
<context>
    <name>BioDeviceView</name>
    <message>
        <source>password login</source>
        <translation type="obsolete">contraseña de acceso</translation>
    </message>
    <message>
        <source>fingerprint</source>
        <translation type="obsolete">huella dactilar</translation>
    </message>
    <message>
        <source>fingerevin</source>
        <translation type="obsolete">fingerevin</translation>
    </message>
    <message>
        <source>iris</source>
        <translation type="obsolete">iris</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FakeDialog</name>
    <message>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GreeterWindow</name>
    <message>
        <source>CN</source>
        <translation type="obsolete">CN</translation>
    </message>
    <message>
        <source>EN</source>
        <translation type="obsolete">ES</translation>
    </message>
</context>
<context>
    <name>GreeterWrapper</name>
    <message>
        <source>failed to start session.</source>
        <translation>Error al iniciar sesión.</translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <source>Login</source>
        <translation type="obsolete">Iniciar sesión</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginWindow</name>
    <message>
        <source>Login</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <source>logged in</source>
        <translation>conectado</translation>
    </message>
    <message>
        <source>login</source>
        <translation>iniciar sesión</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Contraseña: </translation>
    </message>
    <message>
        <source>login:</source>
        <translation type="vanished">iniciar sesión:</translation>
    </message>
    <message>
        <source>Incorrect password, please input again</source>
        <translation type="unfinished">Contraseña incorrecta, por favor ingrese nuevamente</translation>
    </message>
    <message>
        <source>please select the type of authentication</source>
        <translation type="obsolete">Por favor seleccione el tipo de autenticación</translation>
    </message>
    <message>
        <source>Incorrect user name, please input again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished">Ventana principal</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>suspend</source>
        <translation type="obsolete">suspender</translation>
    </message>
    <message>
        <source>restart</source>
        <translation type="obsolete">reiniciar</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation type="obsolete">apagar</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerWindow</name>
    <message>
        <source>Goodbye. Would you like to…</source>
        <translation type="obsolete">Adiós. Te gustaria…</translation>
    </message>
    <message>
        <source>Other users are currently logged in to this computer, shutting down now will also close these other sessions.</source>
        <translation type="vanished">Otros usuarios están actualmente conectados a esta computadora, apagar ahora también cerrará estas otras sesiones.</translation>
    </message>
    <message>
        <source>suspend</source>
        <translation type="vanished">suspender</translation>
    </message>
    <message>
        <source>hibernate</source>
        <translation type="vanished">hibernar</translation>
    </message>
    <message>
        <source>restart</source>
        <translation type="vanished">reiniciar</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation type="vanished">apagar</translation>
    </message>
</context>
<context>
    <name>SessionWindow</name>
    <message>
        <source>select the desktop environment</source>
        <translation type="obsolete">seleccione el entorno de escritorio</translation>
    </message>
    <message>
        <source> (Default)</source>
        <translation type="vanished"> (Defecto)</translation>
    </message>
</context>
<context>
    <name>UserEntry</name>
    <message>
        <source>logged in</source>
        <translation type="vanished">conectado</translation>
    </message>
</context>
<context>
    <name>UsersModel</name>
    <message>
        <source>Guest Session</source>
        <translation>Sesión de invitado</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
